@@ -7,6 +7,8 @@ use simpath::{FileType, Simpath};
 fn main() {
     let flowc = if Path::new(env!("CARGO_MANIFEST_DIR")).join("../target/debug/flowc").exists() {
         "../target/debug/flowc"
+    } else if Path::new(env!("CARGO_MANIFEST_DIR")).join("../target/release/flowc").exists() {
+        "../target/release/flowc"
     } else if Simpath::new("PATH").find_type("flowc", FileType::File).is_ok() {
         "flowc"
     } else {
@@ -14,10 +16,9 @@ fn main() {
     };
 
     if flowc.is_empty() {
-        println!("cargo:warning=Could not find `flowc` in $PATH or `target/debug`, so cannot build flowstdlib");
+        println!("cargo:warning=Could not find `flowc` in $PATH or `target/`, so cannot build flowstdlib");
     } else {
         let mut command = Command::new(flowc);
-        // let mut command = Command::new("../target/debug/flowc");
         // Options for flowc: -g for debug symbols, -d to dump compiler structs, -l for a library build
         let command_args = vec!("-v", "info", "-g", "-d", "-l", env!("CARGO_MANIFEST_DIR"));
 
